Skip to contents

Return a list of container names that are found at the endpoint

Usage

list_container_names(
  endpoint_url = Sys.getenv("AZ_STORAGE_EP"),
  token = get_auth_token()
)

Arguments

endpoint_url

An Azure endpoint URL.

token

An Azure authentication token, or a function that returns one. Uses get_auth_token by default.

Value

A character vector of all container names found