Read any file from Azure storage
Arguments
- container
An Azure container object, as returned by get_container
- file
string The path to the file to be read.
- ...
optional arguments to be passed through to AzureStor::download_blob
Read any file from Azure storage
An Azure container object, as returned by get_container
string The path to the file to be read.
optional arguments to be passed through to AzureStor::download_blob