Skip to contents

Read an rds file from Azure storage

Usage

read_azure_rds(container, file, ...)

Arguments

container

An Azure container object, as returned by get_container

file

string The path to the file to be read.

...

optional arguments to be passed through to AzureStor::storage_load_rds. For example, a compression type (one of c("unknown", "gzip", "bzip2", "xz", "zstd", "none")) can be provided using the argument type, which will be passed on to memDecompress via AzureStor::storage_load_rds.

Value

The data object that was stored in the rds file